@@ -9,20 +9,6 @@ from TkZeroUnitTest import TkTestCase
 
 
 class TextTest(TkTestCase):
-    def test_no_params(self):
-        with self.assertRaises(TypeError):
-            Text()
-
-    def test_bad_params(self):
-        with self.assertRaises(TypeError):
-            Text(parent=1)
-        with self.assertRaises(TypeError):
-            Text(self.root, width=5.5)
-        with self.assertRaises(TypeError):
-            Text(self.root, height=-3.2)
-        with self.assertRaises(TypeError):
-            Text(self.root, wrapping=False)
-
     def test_good_params(self):
         Text(self.root, width=20, height=10,
              wrapping=TextWrap.NoWrapping).grid(row=0, column=0)
@@ -34,8 +20,15 @@ class TextTest(TkTestCase):
         self.assertEqual(t.text, "\n")
         t.text = "Foo"
         self.assertEqual(t.text, "Foo\n")
-        with self.assertRaises(TypeError):
-            t.text = False
+
+    def test_cursor(self):
+        t = Text(self.root)
+        t.grid(row=0, column=0)
+        self.root.update()
+        self.assertEqual(t.cursor, "1.0")
+        t.text = "This text\nhas some\nnewlines."
+        t.cursor = "2.0"
+        self.assertEqual(t.cursor, "2.0")
 
     def test_enabled(self):
         t = Text(self.root)
@@ -44,8 +37,20 @@ class TextTest(TkTestCase):
         t.enabled = False
         self.root.update()
         self.assertFalse(t.enabled)
-        with self.assertRaises(TypeError):
-            t.enabled = "False"
+
+    def test_read_only(self):
+        t = Text(self.root)
+        t.grid(row=0, column=0)
+        self.assertFalse(t.read_only)
+        t.read_only = True
+        self.root.update()
+        self.assertTrue(t.read_only)
+
+    def test_hover(self):
+        t = Text(self.root)
+        t.grid(row=0, column=0)
+        self.root.update()
+        self.assertEqual(type(t.hovering_over), bool)
 
     def test_right_click(self):
         t = Text(self.root)
