@@ -11,21 +11,11 @@ from TkZeroUnitTest import TkTestCase
 
 
 class MainWindowTest(TkTestCase):
-    def test_no_params(self):
-        with self.assertRaises(TypeError):
-            Window()
-
-    def test_bad_params(self):
-        with self.assertRaises(TypeError):
-            Window(parent=1)
-
     def test_title(self):
         window = Window(self.root)
         window.title = "My title"
         window.update()
         self.assertEqual(window.title, "My title")
-        with self.assertRaises(TypeError):
-            window.title = 1234567890
 
     def test_size(self):
         window = Window(self.root)
@@ -35,8 +25,6 @@ class MainWindowTest(TkTestCase):
         self.assertEqual(window.size, Vector.Size(width=400, height=400))
         window.size = (120, 120)
         self.assertEqual(window.size, Vector.Size(width=120, height=120))
-        with self.assertRaises(TypeError):
-            window.size = [200, 100]
 
     def test_position(self):
         window = Window(self.root)
@@ -44,8 +32,6 @@ class MainWindowTest(TkTestCase):
         self.assertEqual(window.position, Vector.Position(x=0, y=0))
         window.position = (100, 100)
         self.assertEqual(window.position, Vector.Position(x=100, y=100))
-        with self.assertRaises(TypeError):
-            window.position = [0, 0]
 
     def test_minimized(self):
         window = Window(self.root)
@@ -55,8 +41,6 @@ class MainWindowTest(TkTestCase):
         window.minimized = False
         window.update()
         self.assertFalse(window.minimized)
-        with self.assertRaises(TypeError):
-            window.minimized = "True"
 
     def test_restored(self):
         window = Window(self.root)
@@ -69,8 +53,6 @@ class MainWindowTest(TkTestCase):
         window.restored = False
         window.update()
         self.assertFalse(window.restored)
-        with self.assertRaises(TypeError):
-            window.restored = "False"
 
     def test_maximized(self):
         window = Window(self.root)
@@ -81,8 +63,6 @@ class MainWindowTest(TkTestCase):
         window.maximized = False
         window.update()
         self.assertFalse(window.maximized)
-        with self.assertRaises(TypeError):
-            window.maximized = "True"
 
     def test_fullscreen(self):
         window = Window(self.root)
@@ -92,8 +72,6 @@ class MainWindowTest(TkTestCase):
         window.full_screen = False
         window.update()
         self.assertFalse(window.full_screen)
-        with self.assertRaises(TypeError):
-            window.full_screen = "la"
 
     def test_binds(self):
         window = Window(self.root)
@@ -101,10 +79,6 @@ class MainWindowTest(TkTestCase):
         window.bind_to_event("<<MyOwnSpecialEvent>>", func, run_in_thread=True)
         binds = window.bind_to_event("<<MyOwnSpecialEvent>>")
         self.assertTrue(len(binds) > 0)
-        with self.assertRaises(TypeError):
-            window.bind_to_event(1234)
-        with self.assertRaises(TypeError):
-            window.bind_to_event("<<event>>", add=1)
         self.root.generate_event("<<MyOwnSpecialEvent>>")
 
     def test_enabled(self):
@@ -117,8 +91,12 @@ class MainWindowTest(TkTestCase):
         window.update()
         window.enabled = False
         self.assertFalse(window.enabled)
-        with self.assertRaises(TypeError):
-            window.enabled = "True"
+
+    def test_hover(self):
+        window = Window(self.root)
+        window.lift()
+        window.update()
+        self.assertEqual(type(window.hovering_over), bool)
 
     def test_on_close(self):
         window = Window(self.root)
