@@ -4,7 +4,7 @@ Creates a themed Combobox.
 
 import tkinter as tk
 from tkinter import ttk
-from typing import Union, Callable
+from typing import Union, Callable, Tuple, List
 
 from TkZero.Platform import on_aqua
 
@@ -13,7 +13,7 @@ class Combobox(ttk.Combobox):
     def __init__(
         self,
         parent: Union[tk.Widget, Union[tk.Tk, tk.Toplevel]],
-        values: Union[list[str, ...], tuple[str, ...]] = (),
+        values: Union[List[str], Tuple[str, ...]] = (),
         width: int = None,
         show: str = None,
         validate: Callable = None,
@@ -35,25 +35,6 @@ class Combobox(ttk.Combobox):
         :param command: The command to run when the value of the combobox
          changes. Defaults to None.
         """
-        if not isinstance(parent, (tk.Widget, tk.Tk, tk.Toplevel)):
-            raise TypeError(
-                f"parent is not a "
-                f"Union[tk.Widget, Union[tk.Tk, tk.Toplevel]]! "
-                f"(type passed in: {repr(type(parent))})"
-            )
-        if not isinstance(values, (tuple, list)):
-            raise TypeError(
-                f"values is not a tuple or a list! "
-                f"(type passed in: {repr(type(values))})"
-            )
-        if not isinstance(width, int) and width is not None:
-            raise TypeError(
-                f"width is not a int! (type passed in: {repr(type(width))})"
-            )
-        if not isinstance(show, str) and show is not None:
-            raise TypeError(
-                f"show is not a str! " f"(type passed in: {repr(type(show))})"
-            )
         self._variable = tk.StringVar(value="")
         if command is not None:
             self._variable.trace_add("write", lambda *args: command())
@@ -69,6 +50,7 @@ class Combobox(ttk.Combobox):
         self._style_root = "TCombobox"
         self._enabled = True
         self._readonly = False
+        self.enable_automatically = True
         if on_aqua(self):
             self.bind("<2>", lambda event: self._popup(event=event))
             self.bind("<Control-1>", lambda event: self._popup(event=event))
@@ -77,6 +59,9 @@ class Combobox(ttk.Combobox):
         if values is not None:
             self["values"] = values
         self._make_context_menu()
+        self._hovering_over = False
+        self.bind("<Enter>", lambda _: self._set_hover_state(True))
+        self.bind("<Leave>", lambda _: self._set_hover_state(False))
 
     @property
     def value(self) -> str:
@@ -95,15 +80,16 @@ class Combobox(ttk.Combobox):
         :param new_text: The new text.
         :return: None.
         """
-        if not isinstance(new_text, str):
-            raise TypeError(
-                f"new_text is not a str! " f"(type passed in: {repr(type(new_text))})"
-            )
+        last_states = self.state()
+        if self.enable_automatically:
+            self.enabled = True
         self.delete(0, tk.END)
         self.insert(0, new_text)
+        if self.enable_automatically:
+            self.state(last_states)
 
     @property
-    def values(self) -> tuple[str, ...]:
+    def values(self) -> Tuple[str, ...]:
         """
         Get the default options you can select.
 
@@ -112,18 +98,13 @@ class Combobox(ttk.Combobox):
         return self["values"] if self["values"] else ()
 
     @values.setter
-    def values(self, new_values: Union[tuple[str, ...], list[str, ...]]) -> None:
+    def values(self, new_values: Union[Tuple[str, ...], List[str]]) -> None:
         """
         Set the default options text on this combobox.
 
         :param new_values: The new options, as a tuple or list of str.
         :return: None.
         """
-        if not isinstance(new_values, (tuple, list)):
-            raise TypeError(
-                f"new_values is not a tuple or a list! "
-                f"(type passed in: {repr(type(new_values))})"
-            )
         self["values"] = tuple([str(thing) for thing in new_values])
 
     @property
@@ -146,11 +127,6 @@ class Combobox(ttk.Combobox):
          for disabled.
         :return: None.
         """
-        if not isinstance(new_state, bool):
-            raise TypeError(
-                f"new_state is not a bool! "
-                f"(type passed in: {repr(type(new_state))})"
-            )
         self._enabled = new_state
         self._readonly = False
         self.state(["!disabled" if self._enabled else "disabled"])
@@ -175,15 +151,28 @@ class Combobox(ttk.Combobox):
          read only.
         :return: None.
         """
-        if not isinstance(new_state, bool):
-            raise TypeError(
-                f"new_state is not a bool! "
-                f"(type passed in: {repr(type(new_state))})"
-            )
         self._enabled = True
         self._readonly = new_state
         self.state(["readonly" if self._readonly else "!readonly"])
 
+    @property
+    def hovering_over(self) -> bool:
+        """
+        Get whether the cursor is hovering over this widget or not.
+
+        :return: A bool.
+        """
+        return self._hovering_over
+
+    def _set_hover_state(self, is_hovering: bool) -> None:
+        """
+        Set whether we are hovering over this widget or not.
+
+        :param is_hovering: A bool.
+        :return: None.
+        """
+        self._hovering_over = is_hovering
+
     def _make_context_menu(self) -> None:
         """
         Initiate the context menu.
@@ -325,9 +314,4 @@ class Combobox(ttk.Combobox):
         :param style_name: The name of the theme as a str, ex. "Warning"
         :return: None.
         """
-        if not isinstance(style_name, str):
-            raise TypeError(
-                f"style_name is not a str! "
-                f"(type passed in: {repr(type(style_name))})"
-            )
         self.configure(style=f"{style_name}.{self._style_root}")
