@@ -32,18 +32,6 @@ class Entry(ttk.Entry):
         :param command: The command to run when the value of the label
          changes. Defaults to None.
         """
-        if not isinstance(parent, (tk.Widget, tk.Tk, tk.Toplevel)):
-            raise TypeError(
-                f"parent is not a "
-                f"Union[tk.Widget, Union[tk.Tk, tk.Toplevel]]! "
-                f"(type passed in: {repr(type(parent))})"
-            )
-        if not isinstance(width, int) and width is not None:
-            raise TypeError(
-                f"width is not a int! (type passed in: {repr(type(width))})"
-            )
-        if not isinstance(show, str) and show is not None:
-            raise TypeError(f"show is not a str! (type passed in: {repr(type(show))})")
         self._variable = tk.StringVar(master=parent, value="")
         if command is not None:
             self._variable.trace_add("write", lambda *args: command())
@@ -64,12 +52,16 @@ class Entry(ttk.Entry):
         self._style_root = "TEntry"
         self._enabled = True
         self._readonly = False
+        self.enable_automatically = True
         if on_aqua(self):
             self.bind("<2>", lambda event: self._popup(event=event))
             self.bind("<Control-1>", lambda event: self._popup(event=event))
         else:
             self.bind("<3>", lambda event: self._popup(event=event))
         self._make_context_menu()
+        self._hovering_over = False
+        self.bind("<Enter>", lambda _: self._set_hover_state(True))
+        self.bind("<Leave>", lambda _: self._set_hover_state(False))
 
     @property
     def value(self) -> str:
@@ -88,12 +80,13 @@ class Entry(ttk.Entry):
         :param new_text: The new text.
         :return: None.
         """
-        if not isinstance(new_text, str):
-            raise TypeError(
-                f"new_text is not a str! " f"(type passed in: {repr(type(new_text))})"
-            )
+        last_states = self.state()
+        if self.enable_automatically:
+            self.enabled = True
         self.delete(0, tk.END)
         self.insert(0, new_text)
+        if self.enable_automatically:
+            self.state(last_states)
 
     @property
     def enabled(self) -> bool:
@@ -115,11 +108,6 @@ class Entry(ttk.Entry):
          for disabled.
         :return: None.
         """
-        if not isinstance(new_state, bool):
-            raise TypeError(
-                f"new_state is not a bool! "
-                f"(type passed in: {repr(type(new_state))})"
-            )
         self._enabled = new_state
         self._readonly = False
         self.state(["!disabled" if self._enabled else "disabled"])
@@ -144,15 +132,28 @@ class Entry(ttk.Entry):
          read only.
         :return: None.
         """
-        if not isinstance(new_state, bool):
-            raise TypeError(
-                f"new_state is not a bool! "
-                f"(type passed in: {repr(type(new_state))})"
-            )
         self._enabled = True
         self._readonly = new_state
         self.state(["readonly" if self._readonly else "!readonly"])
 
+    @property
+    def hovering_over(self) -> bool:
+        """
+        Get whether the cursor is hovering over this widget or not.
+
+        :return: A bool.
+        """
+        return self._hovering_over
+
+    def _set_hover_state(self, is_hovering: bool) -> None:
+        """
+        Set whether we are hovering over this widget or not.
+
+        :param is_hovering: A bool.
+        :return: None.
+        """
+        self._hovering_over = is_hovering
+
     def _make_context_menu(self) -> None:
         """
         Initiate the context menu.
@@ -294,9 +295,4 @@ class Entry(ttk.Entry):
         :param style_name: The name of the theme as a str, ex. "Warning"
         :return: None.
         """
-        if not isinstance(style_name, str):
-            raise TypeError(
-                f"style_name is not a str! "
-                f"(type passed in: {repr(type(style_name))})"
-            )
         self.configure(style=f"{style_name}.{self._style_root}")
