@@ -16,15 +16,12 @@ class Frame(ttk.Frame):
 
         :param parent: The parent of the frame.
         """
-        if not isinstance(parent, (tk.Widget, tk.Tk, tk.Toplevel)):
-            raise TypeError(
-                f"parent is not a "
-                f"Union[tk.Widget, Union[tk.Tk, tk.Toplevel]]! "
-                f"(type passed in: {repr(type(parent))})"
-            )
         super().__init__(master=parent)
         self._style_root = "TFrame"
         self._enabled = True
+        self._hovering_over = False
+        self.bind("<Enter>", lambda _: self._set_hover_state(True))
+        self.bind("<Leave>", lambda _: self._set_hover_state(False))
 
     @property
     def width(self) -> int:
@@ -44,11 +41,6 @@ class Frame(ttk.Frame):
          Cannot be less than 1.
         :return: None.
         """
-        if not isinstance(new_width, int):
-            raise TypeError(
-                f"new_height is not a int! "
-                f"(type passed in: {repr(type(new_width))})"
-            )
         if new_width < 1:
             raise ValueError(
                 f"new_height is less than 1! " f"(value passed in: {repr(new_width)})"
@@ -73,11 +65,6 @@ class Frame(ttk.Frame):
          Cannot be less than 1.
         :return: None.
         """
-        if not isinstance(new_height, int):
-            raise TypeError(
-                f"new_height is not an int! "
-                f"(type passed in: {repr(type(new_height))})"
-            )
         if new_height < 1:
             raise ValueError(
                 f"new_height is less than 1! " f"(value passed in: {repr(new_height)})"
@@ -98,13 +85,16 @@ class Frame(ttk.Frame):
         if parent is None:
             parent = self
         for child in parent.winfo_children():
-            if child.winfo_class() not in ("Frame", "LabelFrame"):
+            if child.winfo_class() not in ("TFrame", "TLabelFrame"):
                 try:
                     child.state(["!disabled" if enable else "disabled"])
                 except AttributeError:
                     child.configure(state=tk.NORMAL if enable else tk.DISABLED)
             else:
-                self._enable_children(parent, enable)
+                if hasattr(child, "enabled"):
+                    child.enabled = enable
+                else:
+                    self._enable_children(child, enable)
 
     @property
     def enabled(self) -> bool:
@@ -126,14 +116,27 @@ class Frame(ttk.Frame):
         for disabled.
         :return: None.
         """
-        if not isinstance(new_state, bool):
-            raise TypeError(
-                f"new_state is not a bool! "
-                f"(type passed in: {repr(type(new_state))})"
-            )
         self._enabled = new_state
         self._enable_children(enable=self._enabled)
 
+    @property
+    def hovering_over(self) -> bool:
+        """
+        Get whether the cursor is hovering over this widget or not.
+
+        :return: A bool.
+        """
+        return self._hovering_over
+
+    def _set_hover_state(self, is_hovering: bool) -> None:
+        """
+        Set whether we are hovering over this widget or not.
+
+        :param is_hovering: A bool.
+        :return: None.
+        """
+        self._hovering_over = is_hovering
+
     def apply_style(self, style_name: str) -> None:
         """
         Apply a theme to this frame.
@@ -141,11 +144,6 @@ class Frame(ttk.Frame):
         :param style_name: The name of the theme as a str, ex. "Warning"
         :return: None.
         """
-        if not isinstance(style_name, str):
-            raise TypeError(
-                f"style_name is not a str! "
-                f"(type passed in: {repr(type(style_name))})"
-            )
         self.configure(style=f"{style_name}.{self._style_root}")
 
 
@@ -210,6 +208,9 @@ class ScrollableFrame(Frame):
         self.frame.bind_all(
             "<KeyRelease-Shift_R>", lambda _: self._set_shift_pressed(False)
         )
+        self._hovering_over = False
+        self.frame.bind("<Enter>", lambda _: self._set_hover_state(True), add=True)
+        self.frame.bind("<Leave>", lambda _: self._set_hover_state(False), add=True)
 
     def _set_shift_pressed(self, is_pressed: bool) -> None:
         """
@@ -270,13 +271,16 @@ class ScrollableFrame(Frame):
         if parent is None:
             parent = self.frame
         for child in parent.winfo_children():
-            if child.winfo_class() not in ("Frame", "LabelFrame"):
+            if child.winfo_class() not in ("TFrame", "TLabelFrame"):
                 try:
                     child.state(["!disabled" if enable else "disabled"])
                 except AttributeError:
                     child.configure(state=tk.NORMAL if enable else tk.DISABLED)
             else:
-                self._enable_children(parent, enable)
+                if hasattr(child, "enabled"):
+                    child.enabled = enable
+                else:
+                    self._enable_children(child, enable)
 
     @property
     def width(self) -> int:
@@ -296,11 +300,6 @@ class ScrollableFrame(Frame):
          Cannot be less than 1.
         :return: None.
         """
-        if not isinstance(new_width, int):
-            raise TypeError(
-                f"new_height is not a int! "
-                f"(type passed in: {repr(type(new_width))})"
-            )
         if new_width < 1:
             raise ValueError(
                 f"new_height is less than 1! " f"(value passed in: {repr(new_width)})"
@@ -326,11 +325,6 @@ class ScrollableFrame(Frame):
          Cannot be less than 1.
         :return: None.
         """
-        if not isinstance(new_height, int):
-            raise TypeError(
-                f"new_height is not an int! "
-                f"(type passed in: {repr(type(new_height))})"
-            )
         if new_height < 1:
             raise ValueError(
                 f"new_height is less than 1! " f"(value passed in: {repr(new_height)})"
@@ -338,6 +332,24 @@ class ScrollableFrame(Frame):
         self.frame.height = new_height
         self.canvas.configure(height=new_height)
 
+    @property
+    def hovering_over(self) -> bool:
+        """
+        Get whether the cursor is hovering over this widget or not.
+
+        :return: A bool.
+        """
+        return self._hovering_over
+
+    def _set_hover_state(self, is_hovering: bool) -> None:
+        """
+        Set whether we are hovering over this widget or not.
+
+        :param is_hovering: A bool.
+        :return: None.
+        """
+        self._hovering_over = is_hovering
+
     def _warn(self, method: str):
         """
         DON'T USE THE GRID, PACK, OR PLACE METHODS ON THE SCROLLABLE FRAME
@@ -370,9 +382,4 @@ class ScrollableFrame(Frame):
         :param style_name: The name of the theme as a str, ex. "Warning"
         :return: None.
         """
-        if not isinstance(style_name, str):
-            raise TypeError(
-                f"style_name is not a str! "
-                f"(type passed in: {repr(type(style_name))})"
-            )
         self.frame.configure(style=f"{style_name}.{self._style_root}")
