@@ -3,7 +3,7 @@ Creates a "classic" Listbox
 """
 
 import tkinter as tk
-from typing import Union, Callable
+from typing import Union, Callable, Tuple, List
 
 
 class SelectModes:
@@ -21,7 +21,7 @@ class Listbox(tk.Listbox):
     def __init__(
         self,
         parent: Union[tk.Widget, Union[tk.Tk, tk.Toplevel]],
-        values: Union[list[str, ...], tuple[str, ...]] = None,
+        values: Union[List[str], Tuple[str, ...]] = None,
         select_mode: str = SelectModes.Single,
         height: int = None,
         width: int = None,
@@ -41,29 +41,6 @@ class Listbox(tk.Listbox):
         :param width: The width of the listbox. Defaults to None.
         :param on_select: The function to call
         """
-        if not isinstance(parent, (tk.Widget, tk.Tk, tk.Toplevel)):
-            raise TypeError(
-                f"parent is not a "
-                f"Union[tk.Widget, Union[tk.Tk, tk.Toplevel]]! "
-                f"(type passed in: {repr(type(parent))})"
-            )
-        if not isinstance(values, (list, tuple)) and values is not None:
-            raise TypeError(
-                f"values is not a list or a tuple! "
-                f"(type passed in: {repr(type(values))})"
-            )
-        if not isinstance(select_mode, str):
-            raise TypeError(
-                f"select_mode is not a str! " f"(type passed in: {repr(type(values))})"
-            )
-        if not isinstance(height, int) and height is not None:
-            raise TypeError(
-                f"height is not a int! (type passed in: {repr(type(height))})"
-            )
-        if not isinstance(width, int) and width is not None:
-            raise TypeError(
-                f"width is not a int! (type passed in: {repr(type(width))})"
-            )
         if values is not None:
             self._values = [str(item) for item in values]
         else:
@@ -81,9 +58,12 @@ class Listbox(tk.Listbox):
         if on_double_click is not None:
             self.bind("<<Double-1>>", lambda event: on_double_click())
         self._enabled = True
+        self._hovering_over = False
+        self.bind("<Enter>", lambda _: self._set_hover_state(True))
+        self.bind("<Leave>", lambda _: self._set_hover_state(False))
 
     @property
-    def selected(self) -> tuple[int]:
+    def selected(self) -> Tuple[int]:
         """
         Get the selected items in this listbox.
 
@@ -92,7 +72,7 @@ class Listbox(tk.Listbox):
         return self.curselection()
 
     @selected.setter
-    def selected(self, new_selection: tuple[int]) -> None:
+    def selected(self, new_selection: Tuple[int]) -> None:
         """
         Set the selected items in this listbox.
 
@@ -100,17 +80,12 @@ class Listbox(tk.Listbox):
          (ex. (0, 1, 3))
         :return: None.
         """
-        if not isinstance(new_selection, tuple):
-            raise TypeError(
-                f"new_selection is not a tuple! "
-                f" (type passed in: {repr(type(new_selection))})"
-            )
         self.selection_clear(0, tk.END)
         for index in new_selection:
             self.selection_set(index)
 
     @property
-    def values(self) -> list[str]:
+    def values(self) -> List[str]:
         """
         Get the values you can select.
 
@@ -119,18 +94,13 @@ class Listbox(tk.Listbox):
         return self._values
 
     @values.setter
-    def values(self, new_values: Union[list[str, ...], tuple[str, ...]]) -> None:
+    def values(self, new_values: Union[List[str], Tuple[str, ...]]) -> None:
         """
         Set the items on this combobox.
 
         :param new_values: The new items, as a list or tuple of str.
         :return: None.
         """
-        if not isinstance(new_values, (list, tuple)):
-            raise TypeError(
-                f"new_values is not a list or a tuple! "
-                f"(type passed in: {repr(type(new_values))})"
-            )
         self._values = [str(item) for item in new_values]
         self._variable.set(self._values)
 
@@ -142,10 +112,6 @@ class Listbox(tk.Listbox):
          list.
         :return: None.
         """
-        if not isinstance(index, int):
-            raise TypeError(
-                f"index is not a int! (type passed in: {repr(type(index))})"
-            )
         if index >= len(self._values):
             raise IndexError(
                 f"index is out of range! "
@@ -174,10 +140,23 @@ class Listbox(tk.Listbox):
          for disabled.
         :return: None.
         """
-        if not isinstance(new_state, bool):
-            raise TypeError(
-                f"new_state is not a bool! "
-                f"(type passed in: {repr(type(new_state))})"
-            )
         self._enabled = new_state
         self.config(state=tk.NORMAL if self._enabled else tk.DISABLED)
+
+    @property
+    def hovering_over(self) -> bool:
+        """
+        Get whether the cursor is hovering over this widget or not.
+
+        :return: A bool.
+        """
+        return self._hovering_over
+
+    def _set_hover_state(self, is_hovering: bool) -> None:
+        """
+        Set whether we are hovering over this widget or not.
+
+        :param is_hovering: A bool.
+        :return: None.
+        """
+        self._hovering_over = is_hovering
