@@ -5,7 +5,9 @@ program!
 
 import tkinter as tk
 from threading import Thread
-from typing import Union, Callable
+from typing import Union, Callable, List, Tuple
+
+from PIL import ImageTk
 
 from TkZero import Platform
 from TkZero import Vector
@@ -20,11 +22,15 @@ class MainWindow(tk.Tk):
     def __init__(self):
         super().__init__()
         self.title = "Main Window"
+        self._icon = None
         self._on_close = None
         self.protocol("WM_DELETE_WINDOW", self.close)
         self._enabled = True
         if Platform.on_aqua(self):
             Menu(self, is_menubar=True)
+        self._hovering_over = False
+        self.bind("<Enter>", lambda _: self._set_hover_state(True))
+        self.bind("<Leave>", lambda _: self._set_hover_state(False))
 
     @property
     def title(self) -> str:
@@ -43,12 +49,29 @@ class MainWindow(tk.Tk):
         :param new_title: A str of the new title for the window.
         :return: None.
         """
-        if not isinstance(new_title, str):
-            raise TypeError(
-                f"new_title is not a str! " f"(type passed in: {repr(type(new_title))})"
-            )
         self.wm_title(new_title)
 
+    @property
+    def icon(self) -> Union[tk.PhotoImage, ImageTk.PhotoImage, None]:
+        """
+        Get the icon of the window. Will return None if the icon was never set
+        before.
+
+        :return: A tk.PhotoImage, a PIL.ImageTk.PhotoImage, or None.
+        """
+        return self._icon
+
+    @icon.setter
+    def icon(self, new_icon: Union[tk.PhotoImage, ImageTk.PhotoImage]) -> None:
+        """
+        Set the icon of the window.
+
+        :param new_icon: A tk.PhotoImage or a PIL.ImageTk.PhotoImage.
+        :return: None.
+        """
+        self._icon = new_icon
+        self.tk.call("wm", "iconphoto", self, new_icon)
+
     @property
     def size(self) -> Vector.Size:
         """
@@ -60,7 +83,7 @@ class MainWindow(tk.Tk):
         return Vector.Size(width=self.winfo_width(), height=self.winfo_height())
 
     @size.setter
-    def size(self, new_size: Union[Vector.Size, tuple[int, int]]) -> None:
+    def size(self, new_size: Union[Vector.Size, Tuple[int, int]]) -> None:
         """
         Set the size of the window.
 
@@ -68,24 +91,6 @@ class MainWindow(tk.Tk):
         height attributes set to the size you want.
         :return: None.
         """
-        if not isinstance(new_size, (Vector.Size, tuple)):
-            raise TypeError(
-                f"new_size is not a Vector.Size or a tuple! "
-                f"(type passed in: {repr(type(new_size))})"
-            )
-        if isinstance(new_size, tuple):
-            if len(new_size) != 2:
-                raise ValueError(
-                    f"new_size has "
-                    f"{'more than' if len(new_size) > 2 else 'less than'}"
-                    f" 2 values! (got: {len(new_size)})"
-                )
-            for index, axis in enumerate(new_size):
-                if not isinstance(axis, int):
-                    raise TypeError(
-                        f"new_size[{index}] is not an int! "
-                        f"(type passed in: {repr(type(axis))})"
-                    )
         if isinstance(new_size, tuple):
             self.geometry(f"{new_size[0]}x{new_size[1]}")
         else:
@@ -103,7 +108,7 @@ class MainWindow(tk.Tk):
         return Vector.Position(x=self.winfo_x(), y=self.winfo_y())
 
     @position.setter
-    def position(self, new_position: Union[Vector.Position, tuple[int, int]]) -> None:
+    def position(self, new_position: Union[Vector.Position, Tuple[int, int]]) -> None:
         """
         Set the **top-left** position of the window.
 
@@ -111,24 +116,6 @@ class MainWindow(tk.Tk):
          x and y attributes.
         :return: None.
         """
-        if not isinstance(new_position, (Vector.Position, tuple)):
-            raise TypeError(
-                f"new_position is not a Vector.Position or a tuple! "
-                f"(type passed in: {repr(type(new_position))})"
-            )
-        if isinstance(new_position, tuple):
-            if len(new_position) != 2:
-                raise ValueError(
-                    f"new_position has "
-                    f"{'more than' if len(new_position) > 2 else 'less than'}"
-                    f" 2 values! (got: {len(new_position)})"
-                )
-            for index, axis in enumerate(new_position):
-                if not isinstance(axis, int):
-                    raise TypeError(
-                        f"new_position[{index}] is not an int! "
-                        f"(type passed in: {repr(type(axis))})"
-                    )
         if isinstance(new_position, tuple):
             self.geometry(
                 f"{self.size.width}x{self.size.height}+"
@@ -157,11 +144,6 @@ class MainWindow(tk.Tk):
         :param to_minimize: A bool on whether to minimize or to restore it.
         :return: None.
         """
-        if not isinstance(to_minimize, bool):
-            raise TypeError(
-                f"to_minimize is not a bool! "
-                f"(type passed in: {repr(type(to_minimize))})"
-            )
         if to_minimize:
             self.iconify()
         else:
@@ -184,11 +166,6 @@ class MainWindow(tk.Tk):
         :param to_restore: A bool on whether to restore or to minimize it.
         :return: None.
         """
-        if not isinstance(to_restore, bool):
-            raise TypeError(
-                f"to_restore is not a bool! "
-                f"(type passed in: {repr(type(to_restore))})"
-            )
         if to_restore:
             self.deiconify()
         else:
@@ -214,11 +191,6 @@ class MainWindow(tk.Tk):
         :param to_mazimize: Whether to maximize the window or minimize it.
         :return: None.
         """
-        if not isinstance(to_mazimize, bool):
-            raise TypeError(
-                f"to_mazimize is not a bool! "
-                f"(type passed in: {repr(type(to_mazimize))})"
-            )
         if to_mazimize:
             if Platform.on_x11(self):
                 self.attributes("-zoomed", True)
@@ -244,11 +216,6 @@ class MainWindow(tk.Tk):
         :param full_screen: Whether to full-screen the window or not.
         :return: None.
         """
-        if not isinstance(full_screen, bool):
-            raise TypeError(
-                f"full_screen is not a bool! "
-                f"(type passed in: {repr(type(full_screen))})"
-            )
         self.attributes("-fullscreen", full_screen)
 
     def bind_to_event(
@@ -257,7 +224,7 @@ class MainWindow(tk.Tk):
         func: Callable = None,
         run_in_thread: bool = False,
         add: bool = False,
-    ) -> Union[None, list[str]]:
+    ) -> Union[None, List[str]]:
         """
         Bind a event to a function.
 
@@ -273,19 +240,6 @@ class MainWindow(tk.Tk):
         :return: A list of functions (As Tk function str) that would be called
          when this event is triggered or None when binding one.
         """
-        if not isinstance(event, str):
-            raise TypeError(
-                f"event is not a str! (type passed in: {repr(type(event))})"
-            )
-        if not isinstance(run_in_thread, bool):
-            raise TypeError(
-                f"run_in_thread is not a bool! "
-                f"(type passed in: {repr(type(run_in_thread))})"
-            )
-        if not isinstance(add, bool):
-            raise TypeError(
-                f"add is not a bool! " f"(type passed in: {repr(type(add))})"
-            )
         if run_in_thread:
             func = Thread(target=func, args=(), daemon=True).start
         binds = self.bind(event, func, add)
@@ -313,24 +267,19 @@ class MainWindow(tk.Tk):
         :param enable: Whether to enable or disable the children.
         :return: None.
         """
-        if not isinstance(parent, tk.Widget) and parent is not None:
-            raise TypeError(
-                f"parent is not a tk.Widget! " f"(type passed in: {repr(type(parent))})"
-            )
-        if not isinstance(enable, bool):
-            raise TypeError(
-                f"enable is not a bool! (type passed in: {repr(type(enable))})"
-            )
         if parent is None:
             parent = self
         for child in parent.winfo_children():
-            if child.winfo_class() not in ("Frame", "LabelFrame"):
+            if child.winfo_class() not in ("TFrame", "TLabelFrame"):
                 try:
                     child.state(["!disabled" if enable else "disabled"])
                 except AttributeError:
                     child.configure(state=tk.NORMAL if enable else tk.DISABLED)
             else:
-                self._enable_children(parent, enable)
+                if hasattr(child, "enabled"):
+                    child.enabled = enable
+                else:
+                    self._enable_children(child, enable)
 
     @property
     def enabled(self) -> bool:
@@ -352,14 +301,27 @@ class MainWindow(tk.Tk):
          for disabled.
         :return: None.
         """
-        if not isinstance(new_state, bool):
-            raise TypeError(
-                f"new_state is not a bool! "
-                f"(type passed in: {repr(type(new_state))})"
-            )
         self._enabled = new_state
         self._enable_children(enable=self._enabled)
 
+    @property
+    def hovering_over(self) -> bool:
+        """
+        Get whether the cursor is hovering over this widget or not.
+
+        :return: A bool.
+        """
+        return self._hovering_over
+
+    def _set_hover_state(self, is_hovering: bool) -> None:
+        """
+        Set whether we are hovering over this widget or not.
+
+        :param is_hovering: A bool.
+        :return: None.
+        """
+        self._hovering_over = is_hovering
+
     @property
     def on_close(self) -> Union[Callable, None]:
         """
