@@ -41,6 +41,7 @@ class Progressbar(ttk.Progressbar):
         length: int,
         mode: str = ProgressModes.Determinate,
         orientation: str = OrientModes.Horizontal,
+        allow_text: bool = True,
     ):
         """
         Initiate a ttk.Scrollbar.
@@ -52,81 +53,75 @@ class Progressbar(ttk.Progressbar):
         :param orientation: The orientation of the scrollbar and what
          direction it should scroll the widget in. Defaults to
          OrientModes.Horizontal and is a str value.
+        :param allow_text: Whether you can add text on this progress bar or
+         not. This can be turned off if it is messing with a theme.
         """
-        if not isinstance(parent, (tk.Widget, tk.Tk, tk.Toplevel)):
-            raise TypeError(
-                f"parent is not a "
-                f"Union[tk.Widget, Union[tk.Tk, tk.Toplevel]]! "
-                f"(type passed in: {repr(type(parent))})"
-            )
-        if not isinstance(length, int):
-            raise TypeError(
-                f"length is not a int! (type passed in: {repr(type(length))})"
-            )
-        if not isinstance(mode, str):
-            raise TypeError(
-                f"mode is not a str! " f"(type passed in: {repr(type(mode))})"
-            )
-        if not isinstance(orientation, str):
-            raise TypeError(
-                f"orientation is not a str! "
-                f"(type passed in: {repr(type(orientation))})"
-            )
-        self._style = ttk.Style()
-        global _pbar_id
-        if mode == OrientModes.Horizontal:
-            self.style_name = f"LabeledProgressbar{_pbar_id}.Horizontal.TProgressbar"
-            self._style.layout(
-                self.style_name,
-                [
-                    (
-                        "Horizontal.Progressbar.trough",
-                        {
-                            "sticky": "nswe",
-                            "children": [
-                                (
-                                    "Horizontal.Progressbar.pbar",
-                                    {"side": "left", "sticky": "ns"},
-                                ),
-                                (f"{self.style_name}.label", {"sticky": ""}),
-                            ],
-                        },
-                    )
-                ],
+        self._allow_text = allow_text
+        if self._allow_text:
+            self._style = ttk.Style()
+            global _pbar_id
+            if mode == OrientModes.Horizontal:
+                self.style_name = (
+                    f"LabeledProgressbar{_pbar_id}.Horizontal.TProgressbar"
+                )
+                self._style.layout(
+                    self.style_name,
+                    [
+                        (
+                            "Horizontal.Progressbar.trough",
+                            {
+                                "sticky": "nswe",
+                                "children": [
+                                    (
+                                        "Horizontal.Progressbar.pbar",
+                                        {"side": "left", "sticky": "ns"},
+                                    ),
+                                    (f"{self.style_name}.label", {"sticky": ""}),
+                                ],
+                            },
+                        )
+                    ],
+                )
+            else:
+                self.style_name = f"LabeledProgressbar{_pbar_id}.Vertical.TProgressbar"
+                self._style.layout(
+                    self.style_name,
+                    [
+                        (
+                            "Vertical.Progressbar.trough",
+                            {
+                                "sticky": "nswe",
+                                "children": [
+                                    (
+                                        "Vertical.Progressbar.pbar",
+                                        {"side": "left", "sticky": "ns"},
+                                    ),
+                                    (f"{self.style_name}.label", {"sticky": ""}),
+                                ],
+                            },
+                        )
+                    ],
+                )
+            _pbar_id += 1
+            # https://stackoverflow.com/a/40348163/10291933
+            self._text = ""
+            super().__init__(
+                master=parent,
+                orient=orientation,
+                length=length,
+                mode=mode,
+                style=self.style_name,
             )
         else:
-            self.style_name = f"LabeledProgressbar{_pbar_id}.Vertical.TProgressbar"
-            self._style.layout(
-                self.style_name,
-                [
-                    (
-                        "Vertical.Progressbar.trough",
-                        {
-                            "sticky": "nswe",
-                            "children": [
-                                (
-                                    "Vertical.Progressbar.pbar",
-                                    {"side": "left", "sticky": "ns"},
-                                ),
-                                (f"{self.style_name}.label", {"sticky": ""}),
-                            ],
-                        },
-                    )
-                ],
+            super().__init__(
+                master=parent, orient=orientation, length=length, mode=mode
             )
-        _pbar_id += 1
-        # https://stackoverflow.com/a/40348163/10291933
-        self._text = ""
-        super().__init__(
-            master=parent,
-            orient=orientation,
-            length=length,
-            mode=mode,
-            style=self.style_name,
-        )
         self._style_root = "TProgressbar"
         self._enabled = True
         self._orientation = orientation
+        self._hovering_over = False
+        self.bind("<Enter>", lambda _: self._set_hover_state(True))
+        self.bind("<Leave>", lambda _: self._set_hover_state(False))
 
     @property
     def value(self) -> float:
@@ -145,11 +140,6 @@ class Progressbar(ttk.Progressbar):
         :param new_value: A float or an int.
         :return: None.
         """
-        if not isinstance(new_value, (float, int)):
-            raise TypeError(
-                f"new_value is not a float or an int! "
-                f"(type passed in: {repr(type(new_value))})"
-            )
         self["value"] = float(new_value)
 
     @property
@@ -169,11 +159,6 @@ class Progressbar(ttk.Progressbar):
         :param new_value: A float or an int.
         :return: None.
         """
-        if not isinstance(new_value, (float, int)):
-            raise TypeError(
-                f"new_value is not a float or an int! "
-                f"(type passed in: {repr(type(new_value))})"
-            )
         self["maximum"] = float(new_value)
 
     @property
@@ -183,6 +168,11 @@ class Progressbar(ttk.Progressbar):
 
         :return: A str.
         """
+        if not self._allow_text:
+            raise ValueError(
+                "Text has been disabled on this progressbar! "
+                "(Enable it at creation with allow_text = True)"
+            )
         return self._text
 
     @text.setter
@@ -193,9 +183,10 @@ class Progressbar(ttk.Progressbar):
         :param new_text: A str.
         :return: None.
         """
-        if not isinstance(new_text, str):
-            raise TypeError(
-                f"new_text is not a str! " f"(type passed in: {repr(type(new_text))})"
+        if not self._allow_text:
+            raise ValueError(
+                "Text has been disabled on this progressbar! "
+                "(Enable it at creation with allow_text = True)"
             )
         self._text = new_text
         self._style.configure(self.style_name, text=self._text)
@@ -220,10 +211,23 @@ class Progressbar(ttk.Progressbar):
          for disabled.
         :return: None.
         """
-        if not isinstance(new_state, bool):
-            raise TypeError(
-                f"new_state is not a bool! "
-                f"(type passed in: {repr(type(new_state))})"
-            )
         self._enabled = new_state
         self.state(["!disabled" if self._enabled else "disabled"])
+
+    @property
+    def hovering_over(self) -> bool:
+        """
+        Get whether the cursor is hovering over this widget or not.
+
+        :return: A bool.
+        """
+        return self._hovering_over
+
+    def _set_hover_state(self, is_hovering: bool) -> None:
+        """
+        Set whether we are hovering over this widget or not.
+
+        :param is_hovering: A bool.
+        :return: None.
+        """
+        self._hovering_over = is_hovering
