@@ -35,27 +35,15 @@ class Scrollbar(ttk.Scrollbar):
         :param widget: The widget to scroll. Defaults to None and should be a
          tk.Widget.
         """
-        if not isinstance(parent, (tk.Widget, tk.Tk, tk.Toplevel)):
-            raise TypeError(
-                f"parent is not a "
-                f"Union[tk.Widget, Union[tk.Tk, tk.Toplevel]]! "
-                f"(type passed in: {repr(type(parent))})"
-            )
-        if not isinstance(orientation, str):
-            raise TypeError(
-                f"orientation is not a str! "
-                f"(type passed in: {repr(type(orientation))})"
-            )
-        if not isinstance(widget, tk.Widget) and widget is not None:
-            raise TypeError(
-                f"widget is not a tk.Widget! " f"(type passed in: {repr(type(widget))})"
-            )
         super().__init__(master=parent, orient=orientation)
         self._style_root = "TScrollbar"
         self._enabled = True
         self._orientation = orientation
         if widget is not None:
             self.attach_to(widget=widget)
+        self._hovering_over = False
+        self.bind("<Enter>", lambda _: self._set_hover_state(True))
+        self.bind("<Leave>", lambda _: self._set_hover_state(False))
 
     def attach_to(self, widget: tk.Widget) -> None:
         """
@@ -64,10 +52,6 @@ class Scrollbar(ttk.Scrollbar):
         :param widget: The widget to scroll. Should be a tk.Widget.
         :return: None.
         """
-        if not isinstance(widget, tk.Widget):
-            raise TypeError(
-                f"widget is not a tk.Widget! " f"(type passed in: {repr(type(widget))})"
-            )
         if self._orientation == OrientModes.Vertical:
             try:
                 self.configure(command=widget.yview)
@@ -125,10 +109,23 @@ class Scrollbar(ttk.Scrollbar):
          for disabled.
         :return: None.
         """
-        if not isinstance(new_state, bool):
-            raise TypeError(
-                f"new_state is not a bool! "
-                f"(type passed in: {repr(type(new_state))})"
-            )
         self._enabled = new_state
         self.state(["!disabled" if self._enabled else "disabled"])
+
+    @property
+    def hovering_over(self) -> bool:
+        """
+        Get whether the cursor is hovering over this widget or not.
+
+        :return: A bool.
+        """
+        return self._hovering_over
+
+    def _set_hover_state(self, is_hovering: bool) -> None:
+        """
+        Set whether we are hovering over this widget or not.
+
+        :param is_hovering: A bool.
+        :return: None.
+        """
+        self._hovering_over = is_hovering
