@@ -2,7 +2,10 @@
 Create a theme.
 """
 
+import tkinter as tk
+from pathlib import Path
 from tkinter import ttk
+from typing import Union
 
 
 class WidgetStyleRoots:
@@ -19,6 +22,31 @@ class WidgetStyleRoots:
     Spinbox = "TSpinbox"
 
 
+def import_theme(root: tk.Tk, path: Union[str, Path]) -> None:
+    """
+    `source` the theme file in Tk. You must call this before using your theme!
+
+    :param root: The root instance of the GUI. Should be a tk.Tk
+    :param path: The path to the theme file. Should be a str or a pathlib.Path
+    :return: None.
+    """
+    path = str(Path(path).resolve())
+    root.tk.call("source", path)
+
+
+def use_theme(root: tk.Tk, theme: str) -> None:
+    """
+    Use an theme!
+
+    :param root: The root instance of the GUI. Should be a tk.Tk
+    :param theme: The name of the theme, either a built-in one or a theme
+     that was "source"d.
+    :return: None.
+    """
+    style = ttk.Style()
+    style.theme_use(theme)
+
+
 def define_style(style_root: str, style_name: str, **kwargs) -> None:
     """
     Define a style that you can use.
@@ -31,13 +59,5 @@ def define_style(style_root: str, style_name: str, **kwargs) -> None:
     :param kwargs: The named arguments for the style. (Like background="red")
     :return: None.
     """
-    if not isinstance(style_root, str):
-        raise TypeError(
-            f"style_root is not a str! " f"(type passed in: {repr(type(style_root))})"
-        )
-    if not isinstance(style_name, str):
-        raise TypeError(
-            f"style_name is not a str! " f"(type passed in: {repr(type(style_name))})"
-        )
     style = ttk.Style()
     style.configure(f"{style_name}.{style_root}", **kwargs)
